from app.core.config import settings


def test_default_logging_only_emits_app_loggers() -> None:
    logging_config = settings.logging

    assert logging_config["handlers"]["null"]["class"] == "logging.NullHandler"
    assert logging_config["root"]["handlers"] == ["null"]
    assert logging_config["loggers"]["app"]["handlers"] == ["console"]
    assert logging_config["loggers"]["app"]["propagate"] is False